@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     AlarmTypeType,
     AnomalyDetectorStateValueType,
@@ -334,7 +336,7 @@ GetMetricStreamOutputTypeDef = TypedDict(
 GetMetricWidgetImageOutputTypeDef = TypedDict(
     "GetMetricWidgetImageOutputTypeDef",
     {
-        "MetricWidgetImage": Union[bytes, IO[bytes]],
+        "MetricWidgetImage": Union[bytes, IO[bytes], StreamingBody],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
